.. module:: cobyqa.models

Quadratic models
================

This module implements classes for representing the quadratic models used by COBYQA.

.. currentmodule:: cobyqa.models

.. autosummary::
    :toctree: generated/

    Interpolation
    Quadratic
    Models
